==> qore-1.14.0.tar.bz2: qore-1.14.0/docs/lang/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Programming Language Reference Manual", "index.html", [
    [ "Qore Language Reference Manual", "index.html", "index" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Bug List", "bug.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", "namespacemembers_vars" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_qore_1_1_dir.html#abe1d5f94d8397ed73190c724dbddfc6a",
"class_qore_1_1_ftp_client.html#ac860bd11c765ed26e9f94bdc359c0d9e",
"class_qore_1_1_hash_key_reverse_iterator.html#a9740114934ef3e6553613f4beee81270",
"class_qore_1_1_object_pair_iterator.html#af494372ac3f9ee40428dc7040b308801",
"class_qore_1_1_range_iterator.html#ab2c4071b0c75ac9f721880e483e3e81a",
"class_qore_1_1_s_q_l_1_1_datasource.html#a5f225523817d0a2d01e68c9aaa40a83a",
"class_qore_1_1_s_s_l_certificate.html#aa032ba7fce14b9fd6ac0181e2a5a2538",
"class_qore_1_1_socket.html#aab67c1ece890cdf79359ba56f1cd2731",
"class_qore_1_1_term_i_o_s.html#ac93293f545a552695b77b55afd5c30ca",
"class_qore_1_1_time_zone.html#ac82e34e1f7c96d3aa5c0a071981a6f4f",
"group__call__type__constants.html#gaff4a6d7250c5c06104dd7ae863f24248",
"group__digest__functions.html#ga14a7dc1fd6565a0ffa61d2dc943ef3e1",
"group__filesystem__functions.html#gada7c93e7806a58bee29f2357039479e1",
"group__math__functions.html#gafaefa5a3af3bfc983dc61aeb7136808c",
"group__parse__options.html#ga969ab84c1a550482cbc6d24e878172e9",
"group__system__and__build__constants.html#gaf309af16653ccf009d207a851a3bc40f",
"namespacemembers_e.html",
"qore_classes.html#inheritance",
"release_notes.html#qore_1_13_new_features",
"struct_qore_1_1_pipe_info.html#ac930bfdae97e32a713d4c7c2a49e8d26"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.14.2.tar.bz2: qore-1.14.2/docs/lang/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Programming Language Reference Manual", "index.html", [
    [ "Qore Language Reference Manual", "index.html", null ],
    [ "Bug List", "bug.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", "namespacemembers_vars" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_qore_1_1_expression.html#a21e8890dbaf5797c13a2235ddce254c2",
"class_qore_1_1_ftp_client.html#afbbcc2baf05d46c3f96fa2d2f8546d86",
"class_qore_1_1_hash_list_iterator.html#a9f6eb7c58db7641827e6c9ed12f70b98",
"class_qore_1_1_output_stream.html",
"class_qore_1_1_read_only_file.html#a487b2f0b5b97ac8958eff649867f97ff",
"class_qore_1_1_s_q_l_1_1_datasource.html#ab6ea0b7e3f9abdaa6516d7131eea4455",
"class_qore_1_1_s_s_l_private_key.html#a7310bce372479a38a90dbc521710256e",
"class_qore_1_1_socket.html#ad4350c9346e37d5f9ece9578718efd6c",
"class_qore_1_1_thread_1_1_auto_gate.html#a516e31337a00c944e12d6c23e832cbf3",
"class_qore_1_1_tree_map.html#a0be7e053d2e93d2f5c7dc2cce99a8ab7",
"class_qore_1_1zzz8listzzz9.html#a89cad7498a6102679b4d2a96d3eceef5",
"functions_func_d.html",
"group__date__and__time__functions.html#gac96ed9dc0e5436a5f77c7fbeb5c5842e",
"group__file__seek__constants.html#gaf3418d7771017bd7551b14aad79900f3",
"group__math__functions.html#ga1a61f3338662e5506b6136432b2ce151",
"group__option__constants.html#ga5d3b3ad72dbc870686836888c5cb92e0",
"group__string__functions.html#ga859e7c350c00ade5ebeb8e2c6a3d9b1f",
"group__warning__constants.html#ga9cc566b485af781c2399391757b5ed42",
"struct_qore_1_1_filesystem_info.html#a1c47999be5732f42dd040a6ca43227e7"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
